@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2003 Nominum, Inc.
+# Copyright (C) 2001-2004 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,17 +13,15 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: rdataclass.py,v 1.8 2003/06/24 02:37:00 halley Exp $
-
 """DNS Rdata Classes.
 
 @var _by_text: The rdata class textual name to value mapping
 @type _by_text: dict
 @var _by_value: The rdata class value to textual name mapping
 @type _by_value: dict
-@var metaclasses: If an rdataclass is a metaclass, there will be a mapping
+@var _metaclasses: If an rdataclass is a metaclass, there will be a mapping
 whose key is the rdatatype value and whose value is True in this dictionary.
-@type metaclasses: dict"""
+@type _metaclasses: dict"""
 
 import re
 
@@ -39,25 +37,28 @@ ANY = 255
 _by_text = {
     'RESERVED0' : RESERVED0,
     'IN' : IN,
-    'INTERNET' : IN,
     'CH' : CH,
-    'CHAOS' : CH,
     'HS' : HS,
-    'HESIOD' : HS,
     'NONE' : NONE,
     'ANY' : ANY
     }
 
-_by_value = {
-    RESERVED0 : 'RESERVED0',
-    IN : 'IN',
-    CH : 'CH',
-    HS : 'HS',
-    NONE : 'NONE',
-    ANY : 'ANY'
-    }
+# We construct the inverse mapping programmatically to ensure that we
+# cannot make any mistakes (e.g. omissions, cut-and-paste errors) that
+# would cause the mapping not to be true inverse.
 
-metaclasses = {
+_by_value = dict([(y, x) for x, y in _by_text.iteritems()])
+
+# Now that we've built the inverse map, we can add class aliases to
+# the _by_text mapping.
+
+_by_text.update({
+    'INTERNET' : IN,
+    'CHAOS' : CH,
+    'HESIOD' : HS
+    })
+
+_metaclasses = {
     NONE : True,
     ANY : True
     }
@@ -70,7 +71,12 @@ class UnknownRdataclass(dns.exception.DNSException):
 
 def from_text(text):
     """Convert text into a DNS rdata class value.
-    @rtype: int"""
+    @param text: the text
+    @type text: string
+    @rtype: int
+    @raises dns.rdataclass.UnknownRdataClass: the class is unknown
+    @raises ValueError: the rdata class value is not >= 0 and <= 65535
+    """
     
     value = _by_text.get(text.upper())
     if value is None:
@@ -78,14 +84,20 @@ def from_text(text):
         if match == None:
             raise UnknownRdataclass
         value = int(match.group(1))
+        if value < 0 or value > 65535:
+            raise ValueError, "class must be between >= 0 and <= 65535"
     return value
 
 def to_text(value):
     """Convert a DNS rdata class to text.
-    @rtype: string"""
-    
+    @param value: the rdata class value
+    @type value: int
+    @rtype: string
+    @raises ValueError: the rdata class value is not >= 0 and <= 65535
+    """
+
     if value < 0 or value > 65535:
-        raise UnknownRdataclass
+        raise ValueError, "class must be between >= 0 and <= 65535"
     text = _by_value.get(value)
     if text is None:
         text = 'CLASS' + `value`
@@ -93,8 +105,10 @@ def to_text(value):
 
 def is_metaclass(rdclass):
     """True if the class is a metaclass.
+    @param rdclass: the rdata class
+    @type rdclass: int
     @rtype: bool"""
     
-    if metaclasses.has_key(rdclass):
+    if _metaclasses.has_key(rdclass):
         return True
     return False
