@@ -1,4 +1,4 @@
-# Copyright (C) 2001-2003 Nominum, Inc.
+# Copyright (C) 2001-2004 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,8 +13,6 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: rdataset.py,v 1.21 2003/08/07 09:10:05 halley Exp $
-
 """DNS rdatasets (an rdataset is a set of rdatas of a given type and class)"""
 
 import random
@@ -32,8 +30,8 @@ import dns.set
 SimpleSet = dns.set.Set
 
 class DifferingCovers(dns.exception.DNSException):
-    """Raised if an attempt is made to add a SIG whose covered type is not
-    the same as that of the other rdatas in the rdataset."""
+    """Raised if an attempt is made to add a SIG/RRSIG whose covered type
+    is not the same as that of the other rdatas in the rdataset."""
     pass
 
 class IncompatibleTypes(dns.exception.DNSException):
@@ -47,12 +45,14 @@ class Rdataset(dns.set.Set):
     @type rdclass: int
     @ivar rdtype: The type of the rdataset
     @type rdtype: int
-    @ivar covers: The covered type.  Usually this value is dns.rdatatype.NONE,
-    but if the rdtype is dns.rdatatype.SIG, then the covers value will be
-    the rdata type the SIG covers.  The library treats the SIG type as if
-    it were a family of types, e.g. SIG(A), SIG(NS), SIG(SOA).  This makes
-    SIGs much easier to work with than if SIGs covering different rdata types
-    were aggregated into a single SIG rdataset.
+    @ivar covers: The covered type.  Usually this value is
+    dns.rdatatype.NONE, but if the rdtype is dns.rdatatype.SIG or
+    dns.rdatatype.RRSIG, then the covers value will be the rdata
+    type the SIG/RRSIG covers.  The library treats the SIG and RRSIG
+    types as if they were a family of
+    types, e.g. RRSIG(A), RRSIG(NS), RRSIG(SOA).  This makes RRSIGs much
+    easier to work with than if RRSIGs covering different rdata
+    types were aggregated into a single RRSIG rdataset.
     @type covers: int
     @ivar ttl: The DNS TTL (Time To Live) value
     @type ttl: int
@@ -113,7 +113,8 @@ class Rdataset(dns.set.Set):
             raise IncompatibleTypes
         if not ttl is None:
             self.update_ttl(ttl)
-        if self.rdtype == dns.rdatatype.SIG:
+        if self.rdtype == dns.rdatatype.RRSIG or \
+           self.rdtype == dns.rdatatype.SIG:
             covers = rd.covers()
             if len(self) == 0 and self.covers == dns.rdatatype.NONE:
                 self.covers = covers
