@@ -1,4 +1,4 @@
-# Copyright (C) 2003 Nominum, Inc.
+# Copyright (C) 2003, 2004 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -13,8 +13,6 @@
 # ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
 # OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
-# $Id: NXT.py,v 1.7 2003/06/30 06:08:27 halley Exp $
-
 import struct
 
 import dns.exception
@@ -31,6 +29,8 @@ class NXT(dns.rdata.Rdata):
     @type bitmap: string
     @see: RFC 2535"""
 
+    __slots__ = ['next', 'bitmap']
+    
     def __init__(self, rdclass, rdtype, next, bitmap):
         super(NXT, self).__init__(rdclass, rdtype)
         self.next = next
@@ -88,6 +88,9 @@ class NXT(dns.rdata.Rdata):
 
     from_wire = classmethod(from_wire)
 
+    def choose_relativity(self, origin = None, relativize = True):
+        self.next = self.next.choose_relativity(origin, relativize)
+        
     def _cmp(self, other):
         v = cmp(self.next, other.next)
         if v == 0:
